@@ -1,9 +1,11 @@
 """Notification model."""
 
-from django.db import models
 from django.conf import settings
+from django.contrib.contenttypes.fields import GenericForeignKey
+from django.contrib.contenttypes.models import ContentType
+from django.db import models
 
-from .fields import JSONField, ListField
+from .fields import JSONField
 
 
 class NotificationQuerySet(models.QuerySet):
@@ -20,7 +22,7 @@ class NotificationQuerySet(models.QuerySet):
         return self.filter(is_read=True)
 
 
-class Notification(models.Model):
+class BaseNotificationModel(models.Model):
     """
     Model for notifications.
 
@@ -54,21 +56,26 @@ class Notification(models.Model):
     User = settings.AUTH_USER_MODEL
 
     class Meta:
-        """Specify ordering for notifications."""
         ordering = ('-id',)
+        abstract = True
 
     source = models.ForeignKey(User, null=True, on_delete=models.CASCADE)
     source_display_name = models.CharField(max_length=150, null=True)
     recipient = models.ForeignKey(
-        User, related_name='notifications', null=True,
-        on_delete=models.CASCADE
+        User, related_name='notifs_notifications', null=True, on_delete=models.CASCADE
     )
     action = models.CharField(max_length=50)
     category = models.CharField(max_length=50)
-    obj = models.IntegerField(null=True, blank=True)
+
+    object_id = models.PositiveIntegerField(null=True, blank=True)
+    content_type = models.ForeignKey(
+        ContentType, on_delete=models.CASCADE, null=True, blank=True
+    )
+    obj = GenericForeignKey('content_type', 'object_id')
+
     url = models.URLField(null=True, blank=True)
     short_description = models.CharField(max_length=100)
-    channels = ListField(max_length=200)
+    channels = JSONField(default=list)
     extra_data = JSONField(default=dict)
     is_read = models.BooleanField(default=False)
 
@@ -81,8 +88,11 @@ class Notification(models.Model):
     def __str__(self):
         if self.source:
             res = '{}: {} {} {} => {}'.format(
-                self.category, self.source, self.action,
-                self.short_description, self.recipient
+                self.category,
+                self.source,
+                self.action,
+                self.short_description,
+                self.recipient,
             )
         else:
             res = self.short_description
@@ -98,11 +108,20 @@ class Notification(models.Model):
         """
         Return JSON representation that can easily be serialized."""
         return {
+            'notification_id': self.id,
             'source': getattr(self.source, 'id', ''),
             'source_display_name': self.source_display_name,
             'recipient': getattr(self.recipient, 'id', ''),
-            'category': self.category, 'action': self.action, 'obj': self.obj,
-            'short_description': self.short_description, 'url': self.url,
-            'channels': self.channels, 'extra_data': self.extra_data,
-            'is_read': self.is_read
+            'category': self.category,
+            'action': self.action,
+            'obj': self.obj,
+            'short_description': self.short_description,
+            'url': self.url,
+            'channels': self.channels,
+            'extra_data': self.extra_data,
+            'is_read': self.is_read,
         }
+
+
+class Notification(BaseNotificationModel):
+    pass
