@@ -1,3 +1,3 @@
 # This file is necessary for registering celery tasks
 
-from .backends.celery import send_notification  # noqa
+from .backends.celery import consume  # noqa
